@@ -3,7 +3,7 @@ BEGIN {
   $Reply::Plugin::ReadLine::AUTHORITY = 'cpan:DOY';
 }
 {
-  $Reply::Plugin::ReadLine::VERSION = '0.29';
+  $Reply::Plugin::ReadLine::VERSION = '0.30';
 }
 use strict;
 use warnings;
@@ -31,7 +31,12 @@ sub new {
         $history
     );
 
-    if ($self->{term}->ReadLine eq 'Term::ReadLine::Gnu') {
+    if ($self->{term}->ReadLine eq 'Term::ReadLine::Perl5') {
+        # output compatible with Term::ReadLine::Gnu
+        $readline::rl_scroll_nextline = 0;
+    }
+
+    if ($self->{term}->ReadLine eq ('Term::ReadLine::Gnu' or 'Term::ReadLine::Perl5')) {
         $self->{term}->StifleHistory($opts{history_length})
             if defined $opts{history_length} && $opts{history_length} >= 0;
     }
@@ -66,7 +71,7 @@ sub DESTROY {
     return if defined $self->{history_length} && $self->{history_length} == 0;
 
     # XXX support more later
-    return unless $self->{term}->ReadLine eq 'Term::ReadLine::Gnu';
+    return unless $self->{term}->ReadLine eq ('Term::ReadLine::Gnu' or 'Term::ReadLine::Perl5');
 
     $self->{term}->WriteHistory($self->{history_file})
         or warn "Couldn't write history to $self->{history_file}";
@@ -95,6 +100,19 @@ sub _register_tab_complete {
             });
         };
     }
+
+    if ($term->ReadLine eq 'Term::ReadLine::Perl5') {
+        $term->Attribs->{completion_function} = sub {
+            my ($text, $line, $start) = @_;
+            my $end = $start + length($text);
+
+            # discard everything after the cursor for completion purposes
+            substr($line, $end) = '';
+
+            my @matches = $weakself->publish('tab_handler', $line);
+            return scalar(@matches) ? @matches : ();
+        };
+    }
 }
 
 1;
@@ -109,7 +127,7 @@ Reply::Plugin::ReadLine - use Term::ReadLine for user input
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
